@@ -38,13 +38,9 @@ MainWindow::MainWindow()
 #endif    
     foreach (Phonon::EffectDescription effectDescription, effectDescriptions) 
     {
-//        qDebug () << effectDescription.name();
+        qDebug () << effectDescription.name();
         if ((effectDescription.name() == "KEqualizer") || (effectDescription.name() == "equalizer-10bands"))
         {
-/*            foreach (QString str, effectDescription.propertyNames())
-            {
-                qDebug() << str << " => " << effectDescription.property(str.toAscii());
-            }*/
             eqEffect = new Phonon::Effect(effectDescription);
 //            qDebug() << "Effect: " << eqEffect;
             int i = 0;
@@ -53,15 +49,24 @@ MainWindow::MainWindow()
                 QString valName = QString ("eq_%1").arg(i++);
                 double dval = settings.value(valName, 0.0).toDouble();
                 eqEffect->setParameterValue(par, dval);
-//                qDebug() << par.name() << " => " << par.minimumValue() << " to " << par.maximumValue();
+                qDebug() << par.name() << " => " << par.minimumValue() << " to " << par.maximumValue();
             }
         }
+        else
+        {
+            Phonon::Effect *tmpEffect = new Phonon::Effect(effectDescription);
+            foreach (Phonon::EffectParameter par, tmpEffect->parameters())
+            {
+                qDebug() << par.name() << " => " << par.minimumValue() << " to " << par.maximumValue();
+            }
+            delete tmpEffect;
+        }
     }
 
-    Phonon::Path path = Phonon::createPath(mediaObject, audioOutput);
-    if (eqEffect)
+    audioPath = Phonon::createPath(mediaObject, audioOutput);
+    if (eqEffect && settings.value("equalizer", false).toBool())
     {
-        path.insertEffect(eqEffect);
+        audioPath.insertEffect(eqEffect);
     }
 
     qsrand (time (NULL));
@@ -220,9 +225,9 @@ void MainWindow::about()
     msg.setModal(true);
     msg.setWindowTitle(tr ("About TomAmp v0.4"));
     msg.setText(tr("TomAmp is a simple playlist-based music player.\n\n"
-                "(c) 2010 Tamas Marki <tmarki@gmail.com>\n\n"
+                "(c) 2010 Tamas Marki <tmarki@gmail.com>\n"
                 "Please send comments and bug reports to the above e-mail address.\n\n"
-                "Icons by Lako of #eperland @ quakenet\n\n"
+                "Icons by Lako of #eperland @ quakenet\n"
                 "Special thanks to Attila Csipa, and the people at talk.maemo.org"));
     msg.exec ();
 }
@@ -954,7 +959,7 @@ void MainWindow::playlistChanged(int from)
             firstGood = i;
         int currentRow = musicTable->rowCount();
         musicTable->insertRow(currentRow);
-        musicTable->setRowHeight(currentRow, (int)(settings.value("rowHeight", DEFAULT_ROW_HEIGHT).toFloat() * 1.3));
+        musicTable->setRowHeight(currentRow, (int)(settings.value("rowHeight", DEFAULT_ROW_HEIGHT).toDouble() * 1.3));
         setRowFromItem (currentRow, plman.getItem(i));
     }
 /*    if (plman.indexOf(mediaObject->currentSource()) < 0)
@@ -1189,19 +1194,31 @@ void MainWindow::showOptions ()
 void MainWindow::showEqualizer ()
 {
     QList<int> vals;
+    QStringList labels;
     if (eqEffect)
     {
         foreach(Phonon::EffectParameter ep, eqEffect->parameters())
         {
-            vals.push_back(int (eqEffect->parameterValue(ep).toDouble() * 10.0));
+            vals.push_back(int (eqEffect->parameterValue(ep).toDouble()));
+            labels.push_back(ep.name());
         }
     }
-    EqualizerDialog* dlg = new EqualizerDialog (this, vals);
+    EqualizerDialog* dlg = new EqualizerDialog (this, vals, labels, settings.value("equalizer", false).toBool ());
     connect (dlg, SIGNAL(equalizerChanged(int,int)), this, SLOT(equalizerChanged(int,int)));
+    connect (dlg, SIGNAL(toggleEqualizer(bool)), this, SLOT(toggleEqualizer(bool)));
     dlg->exec();
     delete dlg;
 }
 
+void MainWindow::toggleEqualizer(bool val)
+{
+    settings.setValue("equalizer", val);
+    if (val)
+        audioPath.insertEffect(eqEffect);
+    else
+        audioPath.removeEffect (eqEffect);
+}
+
 
 void MainWindow::showAddMenu()
 {
@@ -1215,12 +1232,17 @@ void MainWindow::headphoneEvent(QString what,QString how)
         return;
     if (!settings.value("headphoneSense", false).toBool())
         return;
-    if (mediaObject->state() == Phonon::PlayingState)
+    bool present = QDBusInterface ("org.freedesktop.Hal",
+                    "/org/freedesktop/Hal/devices/platform_headphone",
+                    "org.freedesktop.Hal.Device", 
+                    QDBusConnection::systemBus()).call ("GetProperty", "button.state.value").arguments().at(0).toBool();
+
+    if (mediaObject->state() == Phonon::PlayingState && !present)
     {
         pauseAction->trigger();
         autostopped = true;
     }
-    else if (mediaObject->state() == Phonon::PausedState && autostopped)
+    else if (mediaObject->state() == Phonon::PausedState && autostopped && present)
     {
         playAction->trigger();
         autostopped = false;
@@ -1231,7 +1253,7 @@ void MainWindow::equalizerChanged (int ind, int val)
 {
     if (eqEffect)
     {
-        double dval = (double)val / 10.0;
+        double dval = (double)val;
         eqEffect->setParameterValue(eqEffect->parameters()[ind], dval);
         QString valName = QString ("eq_%1").arg(ind);
         settings.setValue(valName, dval);
