@@ -50,15 +50,20 @@
 #include <mediaobject.h>
 #include <volumeslider.h>
 #include <backendcapabilities.h>
+#include <effect.h>
+#include <effectparameter.h>
 #else
 #include <phonon/audiooutput.h>
 #include <phonon/seekslider.h>
 #include <phonon/mediaobject.h>
 #include <phonon/volumeslider.h>
 #include <phonon/backendcapabilities.h>
+#include <phonon/effect.h>
+#include <phonon/effectparameter.h>
 #include <QtDBus>
 #endif
 #include <QList>
+#include <QTimer>
 #include "playlistmanager.h"
 
 class QAction;
@@ -110,6 +115,7 @@ private slots:
 
     void itemRemoved (int i);
     void showOptions ();
+    void showEqualizer ();
     void playlistControl (const QString&);
     void upSelected();
     void downSelected();
@@ -117,6 +123,11 @@ private slots:
     void orientationChanged();
     void showAddMenu();
     void headphoneEvent (QString,QString);
+    void hideVolumeBar();
+    
+    void equalizerChanged (int ind, int val);
+    void controlsToggled ();
+    void toggleEqualizer(bool);
 
 protected:
     void contextMenuEvent (QContextMenuEvent*e);
@@ -135,7 +146,9 @@ private:
     Phonon::MediaObject *mediaObject;
     Phonon::AudioOutput *audioOutput;
     Phonon::VolumeSlider *volumeSlider;
-
+    Phonon::Effect      *eqEffect;
+    Phonon::Path audioPath;
+    
     PlaylistManager plman;
 
     QAction *playAction;
@@ -165,6 +178,8 @@ private:
     QAction *enqueueAction;
     QAction *enqueueActionButton;
     QAction *optionAction;
+    QAction *equalizerAction;
+    QAction *toggleControls;
     QMenu   *contextMenu;
     QMenu   *addMenu;
     QAction *addMenuAddFile;
