@@ -63,7 +63,7 @@ void PlaylistManager::parseAndAddFolder(const QString &dir, bool recursive)
         }
         if (fileSupported(fname))
         {
-            qDebug () << "Adding: " << fname;
+//            qDebug () << "Adding: " << fname;
             items.append(PlaylistItem (PlaylistItem (fname)));
         }
     }
@@ -282,7 +282,7 @@ void PlaylistManager::appendPlaylistPLS(const QString& filename)
 
     foreach (QString l, lines)
     {
-        qDebug() << "Playlist line " << l;
+//        qDebug() << "Playlist line " << l;
         if (l.isEmpty() || l.trimmed().toLower() == "[playlist]" || l.trimmed().toLower() == "version=2"
             || l.trimmed().startsWith(";"))
         {
